@@ -14,18 +14,17 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# IBM OpenAPI SDK Code Generator Version: 99-SNAPSHOT-b414353e-20210324-135924
+# IBM OpenAPI SDK Code Generator Version: 3.33.0-caf29bd0-20210603-225214
  
 """
 Search for resources with the global and shared resource properties repository integrated
-in the IBM Cloud Platform. The search repository stores and searches cloud resources
+in the IBM Cloud platform. The search repository stores and searches cloud resources
 attributes, which categorize or classify resources. A resource is a physical or logical
-component that can be provisioned or reserved for an application or service instance and
-is owned by resource providers, such as Cloud Foundry, IBM containers, or Resource
-Controller, in the IBM Cloud platform. Resources are uniquely identified by a CRN (Cloud
-Resource Naming identifier) or by an IMS ID. The properties of a resource include tags and
-system properties. Both properties are defined in an IBM Cloud billing account, and span
-across many regions.
+component that can be created or reserved for an application or service instance and is
+owned by resource providers, such as Cloud Foundry, IBM Kubernetes Service, or resource
+controller in IBM Cloud. Resources are uniquely identified by a Cloud Resource Name (CRN)
+or by an IMS ID. The properties of a resource include tags and system properties. Both
+properties are defined in an IBM Cloud billing account, and span across many regions.
 """
 
 from typing import Dict, List
@@ -98,21 +97,22 @@ class GlobalSearchV2(BaseService):
         """
         Find instances of resources (v3).
 
-        Find cloud foundry resources, resource controller-enabled resources, or storage
-        and network resources running on classic infrastructure in a specific account ID.
-        You can apply query strings if necessary. To filter results, you can insert a
-        string using the Lucene syntax and the query string is parsed into a series of
-        terms and operators. A term can be a single word or a phrase, in which case the
-        search is performed for all the words, in the same order. To filter for a specific
-        value regardless of the property that contains it, use an asterisk as the key
-        name. Only resources that belong to the account ID and that are accessible by the
-        client are returned. You must use this operation when you need to fetch more than
-        `10000` resource items. The `/v2/resources/search` prohibits paginating through
-        such a big number. On the first call, the operation returns a live cursor on the
-        data that you must use on all the subsequent calls to get the next batch of
-        results until you get the empty result set. By default, the fields returned for
-        every resources are: "crn", "name", "family", "type", "account_id". You can
-        specify the subset of the fields you want in your request.
+        Find Cloud Foundry resources, IAM-enabled resources, or  storage and network
+        resources running on classic infrastructure in a  specific account ID. You can
+        apply query strings if necessary.
+        To filter results, you can insert a string using the Lucene syntax and the  query
+        string is parsed into a series of terms and operators. A term can be  a single
+        word or a phrase, in which case the search is performed for all  the words, in the
+        same order. To filter for a specific value regardless of  the property that
+        contains it, type the search term without specifying a  field. Only resources that
+        belong to the account ID and that are accessible  by the client are returned.
+        You must use `/v3/resources/search` when you need to fetch more than `10000`
+        resource items. The `/v2/resources/search` prohibits paginating through such  a
+        big number. On the first call, the operation returns a live cursor on the  data
+        that you must use on all the subsequent calls to get the next batch of  results
+        until you get the empty result set. By default, the fields returned  for every
+        resource are "crn", "name", "family", "type", and "account_id". You  can specify
+        the subset of the fields you want in your request.
 
         :param str query: (optional) The Lucene-formatted query string. Default to
                '*' if not set.
